@@ -44,7 +44,7 @@ static gboolean move_left (HTMLCursor *cursor, HTMLEngine *e);
 #define _HTML_CURSOR_DEBUG
 
 #ifdef _HTML_CURSOR_DEBUG
-static int gtk_html_cursor_debug_flag = -1;
+static gint gtk_html_cursor_debug_flag = -1;
 
 static void
 debug_location (const HTMLCursor *cursor)
@@ -1050,7 +1050,6 @@ left_in_flow (HTMLCursor *cursor, HTMLEngine *e)
 {
 	gboolean retval;
 
-	retval = TRUE;
 	if (cursor->offset != html_object_get_left_edge_offset (cursor->object, e->painter, cursor->offset) && html_object_is_container (cursor->object)) {
 		HTMLObject *obj;
 
@@ -1163,7 +1162,6 @@ right_in_flow (HTMLCursor *cursor, HTMLEngine *e)
 {
 	gboolean retval;
 
-	retval = TRUE;
 	if (cursor->offset != html_object_get_right_edge_offset (cursor->object, e->painter, cursor->offset)) {
 		if (html_object_is_container (cursor->object)) {
 			HTMLObject *obj;
