@@ -23,7 +23,6 @@
 
 #include <config.h>
 #include <glib.h>
-#include <libart_lgpl/art_rect.h>
 #include <string.h>
 #include "htmlcluev.h"
 #include "htmlengine-edit.h"
@@ -52,7 +51,7 @@ draw_background_helper (HTMLTableCell *cell,
 	HTMLClueV *cluev;
 	GdkPixbuf  *pixbuf = NULL;
 	GdkColor   *color = NULL;
-	int pixel_size = html_painter_get_pixel_size (p);
+	gint pixel_size = html_painter_get_pixel_size (p);
 
 	o = HTML_OBJECT (cell);
 	cluev = HTML_CLUEV (cell);
@@ -179,7 +178,6 @@ draw (HTMLObject *o,
 	HTMLTableCell *cell = HTML_TABLE_CELL (o);
 	GdkRectangle paint;
 
-
 	if (!html_object_intersect (o, &paint, x, y, width, height))
 		return;
 
@@ -268,7 +266,6 @@ get_bg_color (HTMLObject *o,
 		: html_object_get_bg_color (o->parent, p);
 }
 
-
 #define SB if (!html_engine_save_output_string (state,
 #define SE )) return FALSE
 
@@ -289,7 +286,11 @@ save (HTMLObject *self,
 
 	if (cell->have_bgPixmap) {
 		gchar * url = html_image_resolve_image_url (state->engine->widget, cell->bgPixmap->url);
-		SB " BACKGROUND=\"%s\"", url SE;
+		if (!html_engine_save_delims_and_vals (state, " BACKGROUND=\"", url, "\"", NULL))
+		{
+			g_free (url);
+			return FALSE;
+		}
 		g_free (url);
 	}
 	if (cell->cspan != 1)
@@ -449,7 +450,7 @@ void
 html_table_cell_set_bg_pixmap (HTMLTableCell *cell,
 				    HTMLImagePointer *imagePtr)
 {
-	if(imagePtr) {
+	if (imagePtr) {
 		cell->have_bgPixmap = TRUE;
 		cell->bgPixmap = imagePtr;
 	}
